SkiaDawn: Early out in recordProgramInfo

The Dawn backend also requires a live render target to create a
GrProgramDesc.

Bug: chromium:1059890, chromium:1059939
Change-Id: I48490de3aa7dcbe653c3911b269304cb13bb15b5
Reviewed-on: https://skia-review.googlesource.com/c/skia/+/276985
Commit-Queue: Robert Phillips <robertphillips@google.com>
Reviewed-by: Robert Phillips <robertphillips@google.com>
diff --git a/src/gpu/GrDDLContext.cpp b/src/gpu/GrDDLContext.cpp
index f7e6a44..1f77417 100644
--- a/src/gpu/GrDDLContext.cpp
+++ b/src/gpu/GrDDLContext.cpp
@@ -78,8 +78,9 @@
         const GrCaps* caps = this->caps();
 
         if (this->backend() == GrBackendApi::kVulkan ||
-            this->backend() == GrBackendApi::kMetal) {
-            // Currently, both Vulkan and Metal require a live renderTarget to
+            this->backend() == GrBackendApi::kMetal ||
+            this->backend() == GrBackendApi::kDawn) {
+            // Currently, Vulkan, Metal and Dawn require a live renderTarget to
             // compute the key
             return;
         }